@@ -1305,6 +1305,25 @@ def from_type(thing):
        other elements in the lookup.
     4. Finally, if ``thing`` has type annotations for all required arguments,
        it is resolved via :func:`~hypothesis.strategies.builds`.
+
+    There is a valuable recipe for leveraging ``from_type()`` to generate
+    "everything except" values from a specified type. I.e.
+
+    .. code-block:: python
+
+        def everything_except(excluded_types):
+            return (
+                from_type(type).flatmap(from_type)
+                .filter(lambda x: not isinstance(x, excluded_types))
+            )
+
+    For example, ``everything_except(int)`` returns a strategy that can
+    generate anything that ``from_type()`` can ever generate, except for
+    instances of :class:python:int, and excluding instances of types
+    added via :func:~hypothesis.strategies.register_type_strategy.
+
+    This is useful when writing tests which check that invalid input is
+    rejected in a certain way.
     """
     # TODO: We would like to move this to the top level, but pending some major
     # refactoring it's hard to do without creating circular imports.
